@@ -1,5 +1,5 @@
 from .connection import Connection, Protocol, MSGraphProtocol, MSOffice365Protocol
-from .utils import ME_RESOURCE
+from .utils import ME_RESOURCE, consent
 
 
 class Account:
@@ -35,10 +35,11 @@ class Account:
             if scopes is not None:
                 kwargs['scopes'] = self.protocol.get_scopes_for(scopes)
         elif auth_flow_type == 'credentials':
-            # for client credential grant flow solely:
-            # append the default scope if it's not provided
+            # for client credential grant flow solely: add the default scope if it's not provided
             if not scopes:
                 kwargs['scopes'] = [self.protocol.prefix_scope('.default')]
+            else:
+                raise ValueError('Auth flow type "credentials" does not require scopes')
 
             # set main_resource to blank when it's the 'ME' resource
             if self.protocol.default_resource == ME_RESOURCE:
@@ -69,7 +70,7 @@ class Account:
 
         return token is not None and not token.is_expired
 
-    def authenticate(self, *, scopes=None, **kwargs):
+    def authenticate(self, *, scopes=None, handle_consent=consent.consent_input_token, **kwargs):
         """ Performs the oauth authentication flow using the console resulting in a stored token.
         It uses the credentials passed on instantiation
 
@@ -92,10 +93,7 @@ class Account:
 
             consent_url, _ = self.con.get_authorization_url(**kwargs)
 
-            print('Visit the following url to give consent:')
-            print(consent_url)
-
-            token_url = input('Paste the authenticated url here:\n')
+            token_url = handle_consent(consent_url)
 
             if token_url:
                 result = self.con.request_token(token_url, **kwargs)  # no need to pass state as the session is the same
@@ -269,3 +267,13 @@ class Account:
         from .category import Categories
 
         return Categories(parent=self, main_resource=resource)
+
+    def groups(self, *, resource=''):
+        """ Get an instance to read information from Microsoft Groups """
+
+        if not isinstance(self.protocol, MSGraphProtocol):
+            raise RuntimeError(
+                'groups api only works on Microsoft Graph API')
+
+        from .groups import Groups
+        return Groups(parent=self, main_resource=resource)
